(drain env)(drain env max-ticks)Calls tick until there are no more in-flight segments. Will only
call tick 10,000 times, or a user-given number of times, to prevent
an infinite-loop in the case of a problematic job.
Calls `tick` until there are no more in-flight segments. Will only call `tick` 10,000 times, or a user-given number of times, to prevent an infinite-loop in the case of a problematic job.
(drained? env)Returns true if there are no in-flight segments.
Returns true if there are no in-flight segments.
(env-summary env)Returns a subset of the runtime to explain where segments are currently located in the job.
Returns a subset of the runtime to explain where segments are currently located in the job.
(init {:keys [workflow] :as job})Takes an Onyx job and returns a new runtime instance.
Takes an Onyx job and returns a new runtime instance.
(new-segment env input-task segment)Given a runtime, places the segment onto
the inbox of the specified task. Does not call tick
or advance the runtime in any way.
Given a runtime, places the segment onto the inbox of the specified task. Does not call `tick` or advance the runtime in any way.
(stop env)Stops and returns the runtime, simulating the behavior of a
distributed peer stopping. It is valid to call tick after
stop to simulate the job starting again.
Stops and returns the runtime, simulating the behavior of a distributed peer stopping. It is valid to call `tick` after `stop` to simulate the job starting again.
(tick env)(tick env n)Advances the runtime one step in the lifecycle forward for all tasks.
Advances the runtime one step in the lifecycle forward for all tasks.
Data-backed API for transitioning the environment.
Data-backed API for transitioning the environment.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |